<!--(https://raw.githubusercontent.com/physiopy/phys2denoise/master/docs/_static/phys2denoise_card.jpg)-->
<a name="readme"></a>
<!-- <img alt="physiopy" src="https://github.com/physiopy/phys2denoise/blob/master/docs/_static/phys2denoise_logo1280×640.png" height="150"> -->

niutils
=======

This is a quick collection of little (f)MRI utils functions collected together because I found myself using them quite often, packaged in pip to be easy to adopt.
I have no idea nor strict plan to where this project should/could/would go.
If you find yourself using this project (why?) let me know - so I can decide how to properly make it citable. 

**The project is currently (and in perpetuum) under development**.
Any suggestion/bug report is welcome! Feel free to open an issue.

License
-------

Copyright 2021, Stefano Moia.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
